[llvm-commits] [llvm] r102106 - in /llvm/trunk/lib/CodeGen/AsmPrinter: DwarfDebug.cpp DwarfDebug.h

Devang Patel dpatel at apple.com
Thu Apr 22 11:43:35 PDT 2010


Author: dpatel
Date: Thu Apr 22 13:43:35 2010
New Revision: 102106

URL: http://llvm.org/viewvc/llvm-project?rev=102106&view=rev
Log:
Rename InsnAfterLabelMap and InsnBeforeLabelMap.

Modified:
    llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
    llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h

Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp?rev=102106&r1=102105&r2=102106&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.cpp Thu Apr 22 13:43:35 2010
@@ -1393,16 +1393,16 @@
             DebugRangeSymbols.size() * Asm->getTargetData().getPointerSize());
     for (SmallVector<DbgRange, 4>::const_iterator RI = Ranges.begin(),
          RE = Ranges.end(); RI != RE; ++RI) {
-      DebugRangeSymbols.push_back(InsnBeforeLabelMap.lookup(RI->first));
-      DebugRangeSymbols.push_back(InsnAfterLabelMap.lookup(RI->second));
+      DebugRangeSymbols.push_back(LabelsBeforeInsn.lookup(RI->first));
+      DebugRangeSymbols.push_back(LabelsAfterInsn.lookup(RI->second));
     }
     DebugRangeSymbols.push_back(NULL);
     DebugRangeSymbols.push_back(NULL);
     return ScopeDIE;
   }
 
-  MCSymbol *Start = InsnBeforeLabelMap.lookup(RI->first);
-  MCSymbol *End = InsnAfterLabelMap.lookup(RI->second);
+  MCSymbol *Start = LabelsBeforeInsn.lookup(RI->first);
+  MCSymbol *End = LabelsAfterInsn.lookup(RI->second);
 
   if (Start == 0 || End == 0) return 0;
 
@@ -1429,8 +1429,8 @@
   // For now, use first instruction range and emit low_pc/high_pc pair and
   // corresponding .debug_inlined section entry for this pair.
   SmallVector<DbgRange, 4>::const_iterator RI = Ranges.begin();
-  MCSymbol *StartLabel = InsnBeforeLabelMap.lookup(RI->first);
-  MCSymbol *EndLabel = InsnAfterLabelMap.lookup(RI->second);
+  MCSymbol *StartLabel = LabelsBeforeInsn.lookup(RI->first);
+  MCSymbol *EndLabel = LabelsAfterInsn.lookup(RI->second);
 
   if (StartLabel == 0 || EndLabel == 0) {
     assert (0 && "Unexpected Start and End  labels for a inlined scope!");
@@ -2156,7 +2156,7 @@
 
   // If this instruction begins a scope then note down corresponding label.
   if (InsnsBeginScopeSet.count(MI) != 0)
-    InsnBeforeLabelMap[MI] = Label;
+    LabelsBeforeInsn[MI] = Label;
 }
 
 /// endScope - Process end of a scope.
@@ -2165,7 +2165,7 @@
     // Emit a label if this instruction ends a scope.
     MCSymbol *Label = MMI->getContext().CreateTempSymbol();
     Asm->OutStreamer.EmitLabel(Label);
-    InsnAfterLabelMap[MI] = Label;
+    LabelsAfterInsn[MI] = Label;
   }
 }
 
@@ -2512,8 +2512,8 @@
   DeleteContainerSeconds(AbstractScopes);
   AbstractScopesList.clear();
   AbstractVariables.clear();
-  InsnBeforeLabelMap.clear();
-  InsnAfterLabelMap.clear();
+  LabelsBeforeInsn.clear();
+  LabelsAfterInsn.clear();
   Lines.clear();
   PrevLabel = NULL;
 }

Modified: llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h?rev=102106&r1=102105&r2=102106&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h (original)
+++ llvm/trunk/lib/CodeGen/AsmPrinter/DwarfDebug.h Thu Apr 22 13:43:35 2010
@@ -188,13 +188,13 @@
   DenseMap<MDNode*, SmallVector<InlineInfoLabels, 4> > InlineInfo;
   SmallVector<MDNode *, 4> InlinedSPNodes;
 
   /// InsnBeforeLabelMap - Maps instruction with label emitted before 
   /// instruction.
-  DenseMap<const MachineInstr *, MCSymbol *> InsnBeforeLabelMap;
+  DenseMap<const MachineInstr *, MCSymbol *> LabelsBeforeInsn;
 
   /// InsnAfterLabelMap - Maps instruction with label emitted after
   /// instruction.
-  DenseMap<const MachineInstr *, MCSymbol *> InsnAfterLabelMap;
+  DenseMap<const MachineInstr *, MCSymbol *> LabelsAfterInsn;
 
   SmallVector<const MCSymbol *, 8> DebugRangeSymbols;
 
@@ -188,13 +188,13 @@
   SmallVector<MDNode *, 4> InlinedSPNodes;
 
-  /// InsnBeforeLabelMap - Maps instruction with label emitted before 
+  /// LabelsBeforeInsn - Maps instruction with label emitted before 
   /// instruction.
@@ -188,13 +188,13 @@
 
-  /// InsnAfterLabelMap - Maps instruction with label emitted after
+  /// LabelsAfterInsn - Maps instruction with label emitted after
   /// instruction.





More information about the llvm-commits mailing list